Page MenuHomePhabricator

D18322.diff
No OneTemporary

D18322.diff

diff --git a/src/applications/auth/controller/PhabricatorAuthFinishController.php b/src/applications/auth/controller/PhabricatorAuthFinishController.php
--- a/src/applications/auth/controller/PhabricatorAuthFinishController.php
+++ b/src/applications/auth/controller/PhabricatorAuthFinishController.php
@@ -54,7 +54,7 @@
->addHiddenInput(AphrontRequest::TYPE_HISEC, true)
->appendParagraph(
pht(
- 'Welcome, %s. To complete the login process, provide your '.
+ 'Welcome, %s. To complete the process of logging in, provide your '.
'multi-factor credentials.',
phutil_tag('strong', array(), $viewer->getUsername())))
->appendChild($form->buildLayoutView())
diff --git a/src/applications/auth/controller/PhabricatorAuthLoginController.php b/src/applications/auth/controller/PhabricatorAuthLoginController.php
--- a/src/applications/auth/controller/PhabricatorAuthLoginController.php
+++ b/src/applications/auth/controller/PhabricatorAuthLoginController.php
@@ -92,8 +92,8 @@
} else {
return $this->renderError(
pht(
- 'The external account ("%s") you just used to login is already '.
- 'associated with another Phabricator user account. Login to the '.
+ 'The external account ("%s") you just used to log in is already '.
+ 'associated with another Phabricator user account. Log in to the '.
'other Phabricator account and unlink the external account before '.
'linking it to a new Phabricator account.',
$provider->getProviderName()));
@@ -214,7 +214,7 @@
if (!$provider) {
return $this->renderError(
pht(
- 'The account you are attempting to login with uses a nonexistent '.
+ 'The account you are attempting to log in with uses a nonexistent '.
'or disabled authentication provider (with key "%s"). An '.
'administrator may have recently disabled this provider.',
$this->providerKey));
@@ -240,14 +240,14 @@
if ($this->getRequest()->getUser()->isLoggedIn()) {
$crumbs->addTextCrumb(pht('Link Account'), $provider->getSettingsURI());
} else {
- $crumbs->addTextCrumb(pht('Login'), $this->getApplicationURI('start/'));
+ $crumbs->addTextCrumb(pht('Log In'), $this->getApplicationURI('start/'));
}
$crumbs->addTextCrumb($provider->getProviderName());
$crumbs->setBorder(true);
return $this->newPage()
- ->setTitle(pht('Login'))
+ ->setTitle(pht('Log In'))
->setCrumbs($crumbs)
->appendChild($content);
}
@@ -257,9 +257,8 @@
$message) {
$message = pht(
- 'Authentication provider ("%s") encountered an error during login. %s',
- $provider->getProviderName(),
- $message);
+ 'Authentication provider ("%s") encountered an error while attempting '.
+ 'to log in. %s', $provider->getProviderName(), $message);
return $this->renderError($message);
}
diff --git a/src/applications/auth/controller/PhabricatorAuthOneTimeLoginController.php b/src/applications/auth/controller/PhabricatorAuthOneTimeLoginController.php
--- a/src/applications/auth/controller/PhabricatorAuthOneTimeLoginController.php
+++ b/src/applications/auth/controller/PhabricatorAuthOneTimeLoginController.php
@@ -68,7 +68,7 @@
if (!$token) {
return $this->newDialog()
- ->setTitle(pht('Unable to Login'))
+ ->setTitle(pht('Unable to Log In'))
->setShortTitle(pht('Login Failure'))
->appendParagraph(
pht(
@@ -170,7 +170,7 @@
case PhabricatorAuthSessionEngine::ONETIME_USERNAME:
case PhabricatorAuthSessionEngine::ONETIME_RESET:
default:
- $title = pht('Login to Phabricator');
+ $title = pht('Log in to Phabricator');
break;
}
@@ -193,7 +193,7 @@
$dialog = $this->newDialog()
->setTitle($title)
- ->addSubmitButton(pht('Login (%s)', $target_user->getUsername()))
+ ->addSubmitButton(pht('Log In (%s)', $target_user->getUsername()))
->addCancelButton('/');
foreach ($body as $paragraph) {
diff --git a/src/applications/auth/controller/PhabricatorAuthRegisterController.php b/src/applications/auth/controller/PhabricatorAuthRegisterController.php
--- a/src/applications/auth/controller/PhabricatorAuthRegisterController.php
+++ b/src/applications/auth/controller/PhabricatorAuthRegisterController.php
@@ -483,14 +483,14 @@
if ($can_edit_username) {
$form->appendChild(
id(new AphrontFormTextControl())
- ->setLabel(pht('Phabricator Username'))
+ ->setLabel(pht('Username'))
->setName('username')
->setValue($value_username)
->setError($e_username));
} else {
$form->appendChild(
id(new AphrontFormMarkupControl())
- ->setLabel(pht('Phabricator Username'))
+ ->setLabel(pht('Username'))
->setValue($value_username)
->setError($e_username));
}
@@ -546,7 +546,7 @@
} else {
$submit
->addCancelButton($this->getApplicationURI('start/'))
- ->setValue(pht('Register Phabricator Account'));
+ ->setValue(pht('Register Account'));
}
@@ -560,7 +560,7 @@
} else {
$crumbs->addTextCrumb(pht('Register'));
$crumbs->addTextCrumb($provider->getProviderName());
- $title = pht('Phabricator Registration');
+ $title = pht('Create a New Account');
}
$crumbs->setBorder(true);
diff --git a/src/applications/auth/controller/PhabricatorAuthStartController.php b/src/applications/auth/controller/PhabricatorAuthStartController.php
--- a/src/applications/auth/controller/PhabricatorAuthStartController.php
+++ b/src/applications/auth/controller/PhabricatorAuthStartController.php
@@ -198,7 +198,7 @@
$crumbs->addTextCrumb(pht('Login'));
$crumbs->setBorder(true);
- $title = pht('Login to Phabricator');
+ $title = pht('Login');
$view = array(
$header,
$invite_message,
@@ -239,8 +239,8 @@
return $this->newDialog()
->setTitle(pht('Login Required'))
- ->appendParagraph(pht('You must login to take this action.'))
- ->addSubmitButton(pht('Login'))
+ ->appendParagraph(pht('You must log in to take this action.'))
+ ->addSubmitButton(pht('Log In'))
->addCancelButton('/');
}
diff --git a/src/applications/auth/controller/PhabricatorAuthUnlinkController.php b/src/applications/auth/controller/PhabricatorAuthUnlinkController.php
--- a/src/applications/auth/controller/PhabricatorAuthUnlinkController.php
+++ b/src/applications/auth/controller/PhabricatorAuthUnlinkController.php
@@ -104,7 +104,7 @@
pht(
'You can not unlink this account because you have no other '.
'valid login accounts. If you removed it, you would be unable '.
- 'to login. Add another authentication method before removing '.
+ 'to log in. Add another authentication method before removing '.
'this one.'))
->addCancelButton($this->getDoneURI());
diff --git a/src/applications/auth/controller/PhabricatorEmailLoginController.php b/src/applications/auth/controller/PhabricatorEmailLoginController.php
--- a/src/applications/auth/controller/PhabricatorEmailLoginController.php
+++ b/src/applications/auth/controller/PhabricatorEmailLoginController.php
@@ -114,7 +114,7 @@
->setTitle(pht('Check Your Email'))
->setShortTitle(pht('Email Sent'))
->appendParagraph(
- pht('An email has been sent with a link you can use to login.'))
+ pht('An email has been sent with a link you can use to log in.'))
->addCancelButton('/', pht('Done'));
}
}
diff --git a/src/applications/auth/controller/PhabricatorLogoutController.php b/src/applications/auth/controller/PhabricatorLogoutController.php
--- a/src/applications/auth/controller/PhabricatorLogoutController.php
+++ b/src/applications/auth/controller/PhabricatorLogoutController.php
@@ -52,9 +52,9 @@
if ($viewer->getPHID()) {
return $this->newDialog()
- ->setTitle(pht('Log out of Phabricator?'))
+ ->setTitle(pht('Log Out?'))
->appendChild(pht('Are you sure you want to log out?'))
- ->addSubmitButton(pht('Logout'))
+ ->addSubmitButton(pht('Log Out'))
->addCancelButton('/');
}
diff --git a/src/applications/auth/controller/PhabricatorMustVerifyEmailController.php b/src/applications/auth/controller/PhabricatorMustVerifyEmailController.php
--- a/src/applications/auth/controller/PhabricatorMustVerifyEmailController.php
+++ b/src/applications/auth/controller/PhabricatorMustVerifyEmailController.php
@@ -33,7 +33,7 @@
}
$must_verify = pht(
- 'You must verify your email address to login. You should have a '.
+ 'You must verify your email address to log in. You should have a '.
'new email message from Phabricator with verification instructions '.
'in your inbox (%s).',
phutil_tag('strong', array(), $email_address));
diff --git a/src/applications/auth/provider/PhabricatorLDAPAuthProvider.php b/src/applications/auth/provider/PhabricatorLDAPAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorLDAPAuthProvider.php
+++ b/src/applications/auth/provider/PhabricatorLDAPAuthProvider.php
@@ -80,11 +80,11 @@
$dialog->addCancelButton($this->getSettingsURI());
} else {
if ($this->shouldAllowRegistration()) {
- $dialog->setTitle(pht('Login or Register with LDAP'));
- $dialog->addSubmitButton(pht('Login or Register'));
+ $dialog->setTitle(pht('Log In or Register with LDAP'));
+ $dialog->addSubmitButton(pht('Log In or Register'));
} else {
- $dialog->setTitle(pht('Login with LDAP'));
- $dialog->addSubmitButton(pht('Login'));
+ $dialog->setTitle(pht('Log In with LDAP'));
+ $dialog->addSubmitButton(pht('Log In'));
}
if ($mode == 'login') {
$dialog->addCancelButton($this->getStartURI());
@@ -315,7 +315,7 @@
"credentials (which is more complicated, but more powerful).\n\n".
"For many installs, direct binding is sufficient. However, you may ".
"want to search first if:\n\n".
- " - You want users to be able to login with either their username ".
+ " - You want users to be able to log in with either their username ".
" or their email address.\n".
" - The login/username is not part of the distinguished name in ".
" your LDAP records.\n".
@@ -344,16 +344,16 @@
"`sn`, which will work the same way direct binding works:\n\n".
" lang=text,name=Simple Example\n".
" sn\n\n".
- "A slightly more complex configuration might let the user login with ".
+ "A slightly more complex configuration might let the user log in with ".
"either their login name or email address:\n\n".
" lang=text,name=Match Several Attributes\n".
" mail\n".
" sn\n\n".
"If your LDAP directory is more complex, or you want to perform ".
"sophisticated filtering, you can use more complex queries. Depending ".
- "on your directory structure, this example might allow users to login ".
- "with either their email address or username, but only if they're in ".
- "specific departments:\n\n".
+ "on your directory structure, this example might allow users to log ".
+ "in with either their email address or username, but only if they're ".
+ "in specific departments:\n\n".
" lang=text,name=Complex Example\n".
" (&(mail=\${login})(|(departmentNumber=1)(departmentNumber=2)))\n".
" (&(sn=\${login})(|(departmentNumber=1)(departmentNumber=2)))\n\n".
diff --git a/src/applications/auth/provider/PhabricatorPasswordAuthProvider.php b/src/applications/auth/provider/PhabricatorPasswordAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorPasswordAuthProvider.php
+++ b/src/applications/auth/provider/PhabricatorPasswordAuthProvider.php
@@ -100,7 +100,7 @@
public function getDescriptionForCreate() {
return pht(
- 'Allow users to login or register using a username and password.');
+ 'Allow users to log in or register using a username and password.');
}
public function getAdapter() {
@@ -174,8 +174,8 @@
$dialog = id(new AphrontDialogView())
->setSubmitURI($this->getLoginURI())
->setUser($viewer)
- ->setTitle(pht('Login to Phabricator'))
- ->addSubmitButton(pht('Login'));
+ ->setTitle(pht('Log In'))
+ ->addSubmitButton(pht('Log In'));
if ($this->shouldAllowRegistration()) {
$dialog->addCancelButton(
diff --git a/src/applications/conpherence/controller/ConpherenceViewController.php b/src/applications/conpherence/controller/ConpherenceViewController.php
--- a/src/applications/conpherence/controller/ConpherenceViewController.php
+++ b/src/applications/conpherence/controller/ConpherenceViewController.php
@@ -195,7 +195,7 @@
->appendChild(
id(new PHUIButtonView())
->setTag('a')
- ->setText(pht('Login to Participate'))
+ ->setText(pht('Log In to Participate'))
->setHref((string)$login_href));
}
}
diff --git a/src/applications/files/controller/PhabricatorFileLightboxController.php b/src/applications/files/controller/PhabricatorFileLightboxController.php
--- a/src/applications/files/controller/PhabricatorFileLightboxController.php
+++ b/src/applications/files/controller/PhabricatorFileLightboxController.php
@@ -76,7 +76,7 @@
->appendChild(
id(new PHUIButtonView())
->setTag('a')
- ->setText(pht('Login to Comment'))
+ ->setText(pht('Log In to Comment'))
->setHref((string)$login_href));
}
diff --git a/src/applications/oauthserver/application/PhabricatorOAuthServerApplication.php b/src/applications/oauthserver/application/PhabricatorOAuthServerApplication.php
--- a/src/applications/oauthserver/application/PhabricatorOAuthServerApplication.php
+++ b/src/applications/oauthserver/application/PhabricatorOAuthServerApplication.php
@@ -23,7 +23,7 @@
}
public function getFlavorText() {
- return pht('Login with Phabricator');
+ return pht('Log In with Phabricator');
}
public function getApplicationGroup() {
diff --git a/src/applications/ponder/view/PonderAddAnswerView.php b/src/applications/ponder/view/PonderAddAnswerView.php
--- a/src/applications/ponder/view/PonderAddAnswerView.php
+++ b/src/applications/ponder/view/PonderAddAnswerView.php
@@ -72,7 +72,7 @@
->appendChild(
id(new PHUIButtonView())
->setTag('a')
- ->setText(pht('Login to Answer'))
+ ->setText(pht('Log In to Answer'))
->setHref((string)$login_href));
}
diff --git a/src/applications/transactions/view/PhabricatorApplicationTransactionCommentView.php b/src/applications/transactions/view/PhabricatorApplicationTransactionCommentView.php
--- a/src/applications/transactions/view/PhabricatorApplicationTransactionCommentView.php
+++ b/src/applications/transactions/view/PhabricatorApplicationTransactionCommentView.php
@@ -199,7 +199,7 @@
'class' => 'login-to-comment button',
'href' => $uri,
),
- pht('Login to Comment')));
+ pht('Log In to Comment')));
}
$data = array();
diff --git a/src/applications/uiexample/examples/PHUIButtonExample.php b/src/applications/uiexample/examples/PHUIButtonExample.php
--- a/src/applications/uiexample/examples/PHUIButtonExample.php
+++ b/src/applications/uiexample/examples/PHUIButtonExample.php
@@ -158,7 +158,7 @@
->setSize(PHUIButtonView::BIG)
->setColor(PHUIButtonView::GREY)
->setIcon($image)
- ->setText(pht('Login or Register'))
+ ->setText(pht('Log In or Register'))
->setSubtext($icon)
->addClass(PHUI::MARGIN_MEDIUM_RIGHT);
}

File Metadata

Mime Type
text/plain
Expires
Wed, Mar 5, 9:24 AM (3 d, 19 h ago)
Storage Engine
blob
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
7224595
Default Alt Text
D18322.diff (16 KB)

Event Timeline
diff --git a/src/applications/auth/provider/PhabricatorAuthProvider.php b/src/applications/auth/provider/PhabricatorAuthProvider.php
--- a/src/applications/auth/provider/PhabricatorAuthProvider.php
+++ b/src/applications/auth/provider/PhabricatorAuthProvider.php
@@ -389,7 +389,7 @@
* @param AphrontRequest HTTP request.
* @param string Request mode string.
* @param map Additional parameters, see above.
* @return wild Login button.
*/
protected function renderStandardLoginButton(
AphrontRequest $request,
@@ -414,9 +414,9 @@
} else if ($mode == 'invite') {
$button_text = pht('Register Account');
} else if ($this->shouldAllowRegistration()) {
- $button_text = pht('Login or Register');
+ $button_text = pht('Log In or Register');
} else {
- $button_text = pht('Login');
+ $button_text = pht('Log In');
}
$icon = id(new PHUIIconView())
@@ -389,7 +389,7 @@
* @param string Request mode string.
* @param map Additional parameters, see above.
- * @return wild Login button.
+ * @return wild Log in button.
*/
protected function renderStandardLoginButton(